@@ -2,12 +2,11 @@ package Alien::GSL;
 
 use strict;
 use warnings;
-use 5.008001;
 
-our $VERSION = '1.06_01';
-$VERSION =~ tr/_//d;
+our $VERSION = '1.01';
+$VERSION = eval $VERSION;
 
-use base 'Alien::Base';
+use parent 'Alien::Base';
 
 1;
 
@@ -81,7 +80,7 @@ L<Math::GSL>
 
 =head1 SOURCE REPOSITORY
 
-L<https://github.com/PerlAlien/Alien-GSL>
+L<https://github.com/Perl5-Alien/Alien-GSL>
 
 =head1 AUTHOR
 
